# aws_inventory
A dynamic AWS inventory for Ansible

See the examples directory for example files that use aws_inventory.

Examples:  
pip install aws_inventory  
pip install git+https://github.com/zahna/aws_inventory.git#egg=master  
pip install -e git+https://github.com/zahna/aws_inventory.git#egg=master  

Hostnames in the config file can use tags or metadata.  
Examples of useful metadata vars:  
InstanceId  
PublicDnsName  
PublicIpAddress  
PrivateIpAddress  
PrivateDnsName  

config file
